@@ -5,12 +5,9 @@ use Moose::Role;
 # Tests break because tye YAML is invalid...?
 # -dcp
 
-use Best [
-    [ qw[YAML::Syck YAML] ],
-    [ qw[Load Dump] ]
-];
+use YAML::Any qw(Load Dump);
 
-our $VERSION   = '0.23';
+our $VERSION   = '0.24';
 our $AUTHORITY = 'cpan:STEVAN';
 
 requires 'pack';
